@@ -1,16 +1,20 @@
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: CC0-1.0
+
+from __future__ import annotations
+
 import pytest
 
-from pikepdf import Pdf
-
+from pikepdf import Pdf, PdfError
 
 # pylint: disable=redefined-outer-name,pointless-statement,expression-not-assigned
 
 
 @pytest.fixture
 def congress(resources):
-    pdf = Pdf.open(resources / 'congress.pdf')
-    pdfimage = pdf.pages[0].Resources.XObject['/Im0']
-    return pdfimage, pdf
+    with Pdf.open(resources / 'congress.pdf') as pdf:
+        pdfimage = pdf.pages[0].Resources.XObject['/Im0']
+        yield pdfimage, pdf
 
 
 def test_get_equality_stream(congress):
@@ -23,7 +27,7 @@ def test_get_equality_stream(congress):
     with pytest.raises(KeyError):
         image['/NoSuchKey']
 
-    image.get('/NoSuchKey', 42) == 42
+    assert image.get('/NoSuchKey', 42) == 42
 
 
 def test_get_equality_dict(congress):
@@ -31,11 +35,11 @@ def test_get_equality_dict(congress):
 
     assert page.MediaBox == page['/MediaBox'] == page.get('/MediaBox')
 
-    with pytest.raises(RuntimeError):
+    with pytest.raises((RuntimeError, PdfError)):
         page.stream_dict
     with pytest.raises(AttributeError):
         page.NoSuchKey
     with pytest.raises(KeyError):
         page['/NoSuchKey']
 
-    page.get('/NoSuchKey', 42) == 42
+    assert page.get('/NoSuchKey', 42) == 42
